Rdocumentation
powered by
Learn R Programming
FTRLProximal (version 0.3.0)
coef.ftrlprox: coef.ftrlprox
Description
Extract model coefficients.
Usage
"coef"(object, ...)
Arguments
object
The model object
...
additional arguments are not used.
Value
an array with the regression coefficients
Details
This function can be used to extract the coefficients of a model trained using the ftrlprox package.